package com.cm6123.monopoly.game;


/**
 * Represents the banker in a Monopoly game, responsible for managing the game's financial transactions.
 */
public class Banker {
    /**
     * The initial balance of the banker.
     */
    private static final int INITIAL_BALANCE = 5000;

    /**
     * The current balance of the banker.
     */
    private int balance;

    /**
     * Adds money to the banker's balance.
     *
     * @param amount The amount of money to add.
     */
    public void addMoney(final int amount) {
        balance += amount;
    }

    /**
     * Constructs a new Banker instance with the initial balance.
     */
    public Banker() {
        this.balance = INITIAL_BALANCE;
    }

    /**
     * Pays a specified amount of money to a player and deducts this amount from the banker's balance.
     *
     * @param player The player to whom the money is being paid.
     * @param amount The amount of money to pay to the player.
     */
    public void payPlayerMoney(final Player player, final int amount) {
        player.addMoney(amount);
        this.balance -= amount;
    }

    /**
     * Checks if a player has passed the 'Go' (Home) position and pays them accordingly.
     * If the player's position is greater than 1, the banker pays them $0 (as per the Monopoly rules).
     *
     * @param player The player whose position is being checked.
     */
    public void checkIfPlayerPassHome(final Player player) {
        if (player.getPosition() > 1) {
            payPlayerMoney(player, 0);
        }
    }

    /**
     * Retrieves the current balance of the banker.
     *
     * @return The current balance of the banker.
     */
    public int getBalance() {
        return balance;
    }

}
