package com.cm6123.monopoly.game;


import java.util.ArrayList;

/**
 * Represents the ways that the game can end and what would happen after.
 */
public final class GameEndings {

    private GameEndings() {}

        /**
         * Checks if the specified round has reached or exceeded the maximum number of rounds.
         *
         * @param round         The current round number.
         * @param numberOfRounds The maximum number of rounds allowed.
         * @return true if the round has reached or exceeded the maximum number of rounds, false otherwise.
         */
        public static boolean checkRoundsReached (final int round, final int numberOfRounds){
            if (round >= numberOfRounds) {
                System.out.println("Game over! Max rounds reached");
                return true;
            }
            return false;
        }

        /**
         * Determines the winner among the given list of players based on their money.
         * Prints out the winner's name and money amount.
         *
         * @param players The list of players in the game.
         */
        public static void determineWinner (final ArrayList<Player> players){
            Player winner = null;
            int maxMoney = 0;

            for (Player player : players) {
                if (player.getMoney() > maxMoney) {
                    maxMoney = player.getMoney();
                    winner = player;
                }
            }
            if (winner != null) {
                System.out.println("The winner is... " + winner.getName() + " with £" + winner.getMoney() + "!!!!");
            }
        }
    }

