package com.cm6123.monopoly.game;

import com.cm6123.monopoly.dice.Dice;

/**
 * Represents the movement logic in a Monopoly game.
 * This class manages the movement of players on the game board based on dice rolls.
 */
public class Movement {

    /** The size of the game board. */
    private static final int GAME_BOARD_SIZE = 16;


    /** A die object used for rolling. */
    private final Dice dice = new Dice(6);


    /**
     * Simulates rolling two dice for a player and updates their position on the game board based on the dice roll result.
     *
     * @param player The player whose position will be updated.
     */
    public void diceResult(final Player player) {
        // Roll two dice
        int roll1 = dice.roll();
        int roll2 = dice.roll();

        // Calculate total dice result
        int diceResult = roll1 + roll2;
        System.out.println("You rolled " + diceResult);

        // Get current player position
        int currentPosition = player.getPosition();

        // Calculate new position on the game board based on dice result
        int newPosition = (currentPosition + diceResult - 1) % GAME_BOARD_SIZE + 1;

        // Update player's position
        player.setPosition(newPosition);
    }


}
