package com.cm6123.monopoly.game;

import java.util.ArrayList;

/**
 * Represents a player in a Monopoly game.
 * Players have a name, money, position, and can interact with the banker.
 */
public class Player {

    /**
     * The name of the player.
     */
    private String name;

    /**
     * The amount of money the player has.
     */
    private int money;

    /**
     * The position of the player on the game board.
     */
    private int position;


    /**
     * Constructs a new player with the specified name, initial money, and starting position.
     *
     * @param playerName     The name of the player.
     * @param playerMoney    The initial amount of money the player has.
     * @param playerPosition The starting position of the player on the game board.
     */
    public Player(final String playerName, final int playerMoney,  final int playerPosition) {
        this.name = playerName;
        this.money = playerMoney;
        this.position = playerPosition;
    }

    /**
     *
     * @param amount amount of money added to the players balance.
     */
    public void addMoney(final int amount) {
        this.money += amount;
    }

    /**
     * Retrieves the name of the player.
     *
     * @return The name of the player.
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the name of the player.
     *
     * @param playerName
     */
    public void setName(final String playerName) {
        this.name = playerName;
    }

    /**
     * Retrieves the amount of money the player has.
     *
     * @return The amount of money the player has.
     */
    public int getMoney() {
        return money;
    }

    /**
     * Sets the amount of money the player has.
     *
     * @param playerMoney The new amount of money for the player.
     */
    public void setMoney(final int playerMoney) {
        this.money = playerMoney;
    }


    /**
     * Retrieves the current position of the player on the game board.
     *
     * @return The current position of the player.
     */
    public int getPosition() {
        return position;
    }

    /**
     * Sets the current position of the player on the game board.
     *
     * @param playerPosition The new position for the player.
     */
    public void setPosition(final int playerPosition) {
        this.position = playerPosition;
    }

    /** List of all players in the game. */
    public static final ArrayList<Player> PLAYERSINTHEGAME = new ArrayList<>();

    /**
     * Retrieves the list of all players in the game.
     *
     * @return The list of all players.
     */
    public static ArrayList<Player> getPlayers() {
        return PLAYERSINTHEGAME;
    }

}
