package com.cm6123.monopoly;

import com.cm6123.monopoly.game.GameEndings;
import com.cm6123.monopoly.game.Player;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.util.ArrayList;

public class GameEndingsTest {

    /**
     * Tests the checkRoundsReached method of GameEndings.
     * Verifies that the roundsReached flag is true when rounds reach the specified number of rounds.
     */
    @Test
    public void testRoundsReached() {
        int rounds = 10;
        int numberOfRounds = 10;

        // Check if rounds reached matches the specified number of rounds
        boolean roundsReached = GameEndings.checkRoundsReached(rounds, numberOfRounds);

        // Assert that roundsReached is true
        Assertions.assertTrue(roundsReached);
        System.out.println("End game");
    }

    @Test
    public void testDetermineWinner() {
        // Create two players with different initial money
        Player player1 = new Player("Player1", 1000, 0);
        Player player2 = new Player("Player2", 2000, 0);

        // Add players to the game
        ArrayList<Player> players = Player.getPlayers();
        players.add(player1);
        players.add(player2);

        // Determine the winner
        GameEndings.determineWinner(players);

        // Assert that the player with more money is identified as the winner
        Player winner = players.stream().max((p1, p2) -> Integer.compare(p1.getMoney(), p2.getMoney())).orElse(null);
        Assertions.assertNotNull(winner);
        Assertions.assertEquals("Player2", winner.getName());
        System.out.println(winner.getName() + " is the winner");
    }
}

